@@ -32,8 +32,8 @@ def main(config_path):
     metric_data = inp.work(config,config_path)
     
     for doc in metric_data:
-        doc["_plugin"] =  "etl"
-        doc["_documentType"]  = "etl"
+        doc["_plugin"] =  "etlReport"
+        doc["_documentType"]  = doc["type"]
         doc["_tag_Name"] = config.get("tags",{}).get("Name","")
         doc["_tag_appName"] = config.get("tags",{}).get("appName","")
         doc["_tag_projectName"] = config.get("tags",{}).get("projectName","")
